@@ -23,8 +23,6 @@ except IOError:
 
 
 include_files = [
-    (os.path.join('tryton', 'data'), 'data'),
-    (os.path.join('tryton', 'plugins'), 'plugins'),
     (os.path.join(sys.prefix, 'share', 'glib-2.0', 'schemas'),
         os.path.join('share', 'glib-2.0', 'schemas')),
     (os.path.join(sys.prefix, 'lib', 'gtk-3.0'),
@@ -33,14 +31,12 @@ include_files = [
         os.path.join('lib', 'gdk-pixbuf-2.0')),
     (os.path.join(sys.prefix, 'lib', 'evince'),
         os.path.join('lib', 'evince')),
-    (os.path.join(sys.prefix, 'share', 'locale'),
-        os.path.join('share', 'locale')),
     (os.path.join(sys.prefix, 'share', 'icons', 'Adwaita'),
         os.path.join('share', 'icons', 'Adwaita')),
     (os.path.join(sys.platform, 'gtk-3.0', 'gtk.immodules'),
-        os.path.join('etc', 'gtk-3.0', 'gtk.immodules')),
+        os.path.join('share', 'gtk-3.0', 'gtk.immodules')),
     (os.path.join(sys.platform, 'gtk-3.0', 'gdk-pixbuf.loaders'),
-        os.path.join('etc', 'gtk-3.0', 'gdk-pixbuf.loaders')),
+        os.path.join('share', 'gtk-3.0', 'gdk-pixbuf.loaders')),
     ]
 
 required_gi_namespaces = [
@@ -70,7 +66,10 @@ def replace_path(match):
     libs = [os.path.basename(p) for p in match.group(1).split(',')]
     required_libs.update(libs)
     if sys.platform == 'darwin':
-        libs = [os.path.join('@executable_path', l) for l in libs]
+        prefix = '@executable_path/lib'
+    else:
+        prefix = 'lib'
+    libs = [os.path.join(prefix, l) for l in libs]
     return 'shared-library="%s"' % ','.join(libs)
 
 
@@ -109,14 +108,14 @@ for lib in required_libs:
             break
     else:
         raise Exception('%s not found' % lib)
-    include_files.append((path, lib))
+    include_files.append((path, os.path.join('lib', lib)))
 
 ssl_paths = ssl.get_default_verify_paths()
 include_files.append(
-    (ssl_paths.openssl_cafile, os.path.join('etc', 'ssl', 'cert.pem')))
+    (ssl_paths.openssl_cafile, os.path.join('share', 'ssl', 'cert.pem')))
 if os.path.exists(ssl_paths.openssl_capath):
     include_files.append(
-        (ssl_paths.openssl_capath, os.path.join('etc', 'ssl', 'certs')))
+        (ssl_paths.openssl_capath, os.path.join('share', 'ssl', 'certs')))
 
 version = Popen(
     'python3 ./setup.py --version', stdout=PIPE, shell=True, encoding='utf-8'
